@@ -262,6 +262,82 @@ Arnolfini.getPrevEvent = function (slideshow)
 	}
 }
 
+mediaShow.getContentListing = function (slideshow)
+{
+    var URL, querystring;
+    //extract passed query string
+    if (slideshow.url.indexOf("?") != -1)
+    {
+        //there is a query string
+        querystring = slideshow.url.slice(slideshow.url.indexOf("?") +1)
+        slideshow.url = slideshow.url.slice(0, slideshow.url.indexOf("?"))
+    }
+    else
+    {
+        //There is no query string
+        querystring = ""
+    }
+    
+    if (slideshow.recursive)
+    {
+        if (querystring == "")
+        {
+            URL = slideshow.url + '/mediaShowListing';
+        }
+        else
+        {
+            URL = slideshow.url + '/mediaShowListing' + '?' + querystring;
+        }
+    }
+    else
+    {
+        if (querystring == "")
+        {
+            URL = slideshow.url + '/mediaShowListing?recursive=false'
+        }
+        else
+        {
+            URL = slideshow.url + '/mediaShowListing' + '?' + querystring + "&recursive=false";
+        }
+    }
+    
+    $.getJSON(URL, function(data) {
+
+        $.each(data, function(index, item) {
+            //-------------------- Declaration of Slide ------------------
+            slideshow.slides.push({
+                "url":item.url,
+                "UID" : item.UID,
+                "loaded": mediaShow.NOT_LOADED
+                });
+            slideshow.size++;
+        });
+        
+        if (slideshow.slides.length == 0)
+        {
+            $.each(mediaShow.slideshows, function(index, item){
+                if(slideshow == item)
+                {
+                    mediaShow.slideshows.splice(index,1);
+                    slideshow.obj.remove();
+                }
+            });
+        }
+        else
+        {
+            //If there is only one slide disable the buttons
+            if (slideshow.slides.length == 1)
+            {
+		if (onSlodeshowSkipPrev == null)
+		{
+			$(slideshow.obj).find(".mediaShowButtons").addClass("disabled")
+		}
+            }
+            mediaShow.markAsInitialized(slideshow);
+        }
+    });
+}
+
 $(document).ready(function() {
 	Arnolfini.events();
 	Arnolfini.archiveShowButtons();
