@@ -1,6 +1,8 @@
 from plone.app.search.browser import Search
 from Products.Five import BrowserView
 from plone.app.layout.viewlets.common import FooterViewlet
+from plone.app.layout.viewlets.common import ViewletBase
+from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from AccessControl import getSecurityManager
 from zope.interface import implements
 from Products.CMFCore.utils import getToolByName
@@ -431,4 +433,22 @@ class Footer(FooterViewlet):
         if not secman.checkPermission('Portlets: Manage portlets', self.context):
             return False
         else:
-            return True
\ No newline at end of file
+            return True
+        
+class TitleViewlet(ViewletBase):
+    """
+    Changing the title format
+    """
+    index = ViewPageTemplateFile('title.pt')
+
+    def update(self):
+        portal_state = getMultiAdapter((self.context, self.request),
+                                        name=u'plone_portal_state')
+        context_state = getMultiAdapter((self.context, self.request),
+                                         name=u'plone_context_state')
+        page_title = escape(safe_unicode(context_state.object_title()))
+        portal_title = escape(safe_unicode(portal_state.navigation_root_title()))
+        if page_title == portal_title:
+            self.site_title = portal_title
+        else:
+            self.site_title = u"%s &larr; %s" % (page_title, portal_title)
